summaryrefslogtreecommitdiff
path: root/StdLib/EfiSocketLib/Udp4.c
diff options
context:
space:
mode:
authorjiaxinwu <jiaxin.wu@intel.com>2015-07-08 03:12:58 +0000
committerjiaxinwu <jiaxinwu@Edk2>2015-07-08 03:12:58 +0000
commitc581e5037dca6e1446972aed194f13c9cdd0b01b (patch)
tree3513f905f8a8172c91d2b14e21af88136b5cd12f /StdLib/EfiSocketLib/Udp4.c
parent395616868f51df1aba68c6ae692b56082d754c10 (diff)
StdLib: Remove EfiSocketLib and Ip4Config Protocol dependency.
Contributed-under: TianoCore Contribution Agreement 1.0 Signed-off-by: jiaxinwu <jiaxin.wu@intel.com> Reviewed-by: "Leahy, Leroy P" <leroy.p.leahy@intel.com> git-svn-id: https://svn.code.sf.net/p/edk2/code/trunk/edk2@17875 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'StdLib/EfiSocketLib/Udp4.c')
-rw-r--r--StdLib/EfiSocketLib/Udp4.c76
1 files changed, 42 insertions, 34 deletions
diff --git a/StdLib/EfiSocketLib/Udp4.c b/StdLib/EfiSocketLib/Udp4.c
index 7fece75095..ef2f9e321b 100644
--- a/StdLib/EfiSocketLib/Udp4.c
+++ b/StdLib/EfiSocketLib/Udp4.c
@@ -1,7 +1,7 @@
/** @file
Implement the UDP4 driver support for the socket layer.
- Copyright (c) 2011, Intel Corporation
+ Copyright (c) 2011 - 2015, Intel Corporation
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -1049,8 +1049,8 @@ EslUdp4VerifyLocalIpAddress (
)
{
UINTN DataSize;
- EFI_IP4_IPCONFIG_DATA * pIpConfigData;
- EFI_IP4_CONFIG_PROTOCOL * pIpConfigProtocol;
+ EFI_IP4_CONFIG2_INTERFACE_INFO * pIfInfo;
+ EFI_IP4_CONFIG2_PROTOCOL * pIpConfig2Protocol;
ESL_SERVICE * pService;
EFI_STATUS Status;
@@ -1059,7 +1059,7 @@ EslUdp4VerifyLocalIpAddress (
//
// Use break instead of goto
//
- pIpConfigData = NULL;
+ pIfInfo = NULL;
for ( ; ; ) {
//
// Determine if the IP address is specified
@@ -1087,12 +1087,14 @@ EslUdp4VerifyLocalIpAddress (
// Open the configuration protocol
//
pService = pPort->pService;
- Status = gBS->OpenProtocol ( pService->Controller,
- &gEfiIp4ConfigProtocolGuid,
- (VOID **)&pIpConfigProtocol,
- NULL,
- NULL,
- EFI_OPEN_PROTOCOL_GET_PROTOCOL );
+ Status = gBS->OpenProtocol (
+ pService->Controller,
+ &gEfiIp4Config2ProtocolGuid,
+ (VOID **)&pIpConfig2Protocol,
+ NULL,
+ NULL,
+ EFI_OPEN_PROTOCOL_GET_PROTOCOL
+ );
if ( EFI_ERROR ( Status )) {
DEBUG (( DEBUG_ERROR,
"ERROR - IP Configuration Protocol not available, Status: %r\r\n",
@@ -1101,39 +1103,45 @@ EslUdp4VerifyLocalIpAddress (
}
//
- // Get the IP configuration data size
+ // Get the interface information size
//
DataSize = 0;
- Status = pIpConfigProtocol->GetData ( pIpConfigProtocol,
- &DataSize,
- NULL );
+ Status = pIpConfig2Protocol->GetData (
+ pIpConfig2Protocol,
+ Ip4Config2DataTypeInterfaceInfo,
+ &DataSize,
+ NULL
+ );
if ( EFI_BUFFER_TOO_SMALL != Status ) {
DEBUG (( DEBUG_ERROR,
- "ERROR - Failed to get IP Configuration data size, Status: %r\r\n",
+ "ERROR - Failed to get the interface information size, Status: %r\r\n",
Status ));
break;
}
//
// Allocate the configuration data buffer
//
- pIpConfigData = AllocatePool ( DataSize );
- if ( NULL == pIpConfigData ) {
+ pIfInfo = AllocatePool ( DataSize );
+ if ( NULL == pIfInfo ) {
DEBUG (( DEBUG_ERROR,
- "ERROR - Not enough memory to allocate IP Configuration data!\r\n" ));
+ "ERROR - Not enough memory to allocate the interface information buffer!\r\n" ));
Status = EFI_OUT_OF_RESOURCES;
break;
}
//
- // Get the IP configuration
+ // Get the interface info.
//
- Status = pIpConfigProtocol->GetData ( pIpConfigProtocol,
- &DataSize,
- pIpConfigData );
+ Status = pIpConfig2Protocol->GetData (
+ pIpConfig2Protocol,
+ Ip4Config2DataTypeInterfaceInfo,
+ &DataSize,
+ pIfInfo
+ );
if ( EFI_ERROR ( Status )) {
DEBUG (( DEBUG_ERROR,
- "ERROR - Failed to return IP Configuration data, Status: %r\r\n",
+ "ERROR - Failed to return the interface info, Status: %r\r\n",
Status ));
break;
}
@@ -1143,19 +1151,19 @@ EslUdp4VerifyLocalIpAddress (
//
DEBUG (( DEBUG_BIND,
"Actual adapter IP address: %d.%d.%d.%d\r\n",
- pIpConfigData->StationAddress.Addr [ 0 ],
- pIpConfigData->StationAddress.Addr [ 1 ],
- pIpConfigData->StationAddress.Addr [ 2 ],
- pIpConfigData->StationAddress.Addr [ 3 ]));
+ pIfInfo->StationAddress.Addr [ 0 ],
+ pIfInfo->StationAddress.Addr [ 1 ],
+ pIfInfo->StationAddress.Addr [ 2 ],
+ pIfInfo->StationAddress.Addr [ 3 ]));
//
// Assume the port is not configured
//
Status = EFI_SUCCESS;
- if (( pConfigData->StationAddress.Addr [ 0 ] == pIpConfigData->StationAddress.Addr [ 0 ])
- && ( pConfigData->StationAddress.Addr [ 1 ] == pIpConfigData->StationAddress.Addr [ 1 ])
- && ( pConfigData->StationAddress.Addr [ 2 ] == pIpConfigData->StationAddress.Addr [ 2 ])
- && ( pConfigData->StationAddress.Addr [ 3 ] == pIpConfigData->StationAddress.Addr [ 3 ])) {
+ if (( pConfigData->StationAddress.Addr [ 0 ] == pIfInfo->StationAddress.Addr [ 0 ])
+ && ( pConfigData->StationAddress.Addr [ 1 ] == pIfInfo->StationAddress.Addr [ 1 ])
+ && ( pConfigData->StationAddress.Addr [ 2 ] == pIfInfo->StationAddress.Addr [ 2 ])
+ && ( pConfigData->StationAddress.Addr [ 3 ] == pIfInfo->StationAddress.Addr [ 3 ])) {
break;
}
@@ -1169,8 +1177,8 @@ EslUdp4VerifyLocalIpAddress (
//
// Free the buffer if necessary
//
- if ( NULL != pIpConfigData ) {
- FreePool ( pIpConfigData );
+ if ( NULL != pIfInfo ) {
+ FreePool ( pIfInfo );
}
//
@@ -1101,39 +1103,45 @@ EslUdp4VerifyLocalIpAddress (
}
//
- // Allocate the configuration data buffer
+ // Allocate the interface information buffer
//